@@ -15,12 +15,16 @@ public class TextListener extends TCPListener {
       BufferedReader in=new BufferedReader(new InputStreamReader(
                           socket.getInputStream()));
       _out=new PrintStream(socket.getOutputStream());
+      fireConnected();
       while (true) {
         String read=in.readLine();
         if (read==null) break;
         synchronized (_data) { _data=_data+read+"\n"; }
       }
-    } catch (Exception ex) { }
+    } catch (Exception ex) {
+    } finally {
+      fireDisconnected();
+    }
 
     try { socket.close(); } catch (Exception ex) { }
     _isConnected=false;
